==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/NewBaseAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.subsystem.BaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.NewBaseAttribute;
import io.ciera.tool.sql.ooaofooa.subsystem.NewBaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.BaseAttributeSetImpl;

import java.util.Arrays;
import java.util.List;


public class NewBaseAttributeSetImpl extends InstanceSet<NewBaseAttributeSet,NewBaseAttribute> implements NewBaseAttributeSet {

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( NewBaseAttribute newbaseattribute : this ) newbaseattribute.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( NewBaseAttribute newbaseattribute : this ) newbaseattribute.setAttr_ID( ref_Attr_ID );
    }


    // selections
    @Override
    public BaseAttributeSet R107_is_a_BaseAttribute() throws XtumlException {
        BaseAttributeSet baseattributeset = new BaseAttributeSetImpl();
        for ( NewBaseAttribute newbaseattribute : this ) baseattributeset.add( newbaseattribute.R107_is_a_BaseAttribute() );
        return baseattributeset;
    }


    @Override
    public NewBaseAttribute nullElement() {
        return NewBaseAttributeImpl.EMPTY_NEWBASEATTRIBUTE;
    }

    @Override
    public NewBaseAttributeSet emptySet() {
      return new NewBaseAttributeSetImpl();
    }

    @Override
    public NewBaseAttributeSet value() {
        return this;
    }

    @Override
    public List<NewBaseAttribute> elements() {
        return Arrays.asList(toArray(new NewBaseAttribute[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/NewBaseAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.subsystem.BaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.NewBaseAttribute;
import io.ciera.tool.sql.ooaofooa.subsystem.NewBaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.BaseAttributeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class NewBaseAttributeSetImpl extends InstanceSet<NewBaseAttributeSet,NewBaseAttribute> implements NewBaseAttributeSet {

    public NewBaseAttributeSetImpl() {
    }

    public NewBaseAttributeSetImpl(Comparator<? super NewBaseAttribute> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( NewBaseAttribute newbaseattribute : this ) newbaseattribute.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( NewBaseAttribute newbaseattribute : this ) newbaseattribute.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public BaseAttributeSet R107_is_a_BaseAttribute() throws XtumlException {
        BaseAttributeSet baseattributeset = new BaseAttributeSetImpl();
        for ( NewBaseAttribute newbaseattribute : this ) baseattributeset.add( newbaseattribute.R107_is_a_BaseAttribute() );
        return baseattributeset;
    }


    @Override
    public NewBaseAttribute nullElement() {
        return NewBaseAttributeImpl.EMPTY_NEWBASEATTRIBUTE;
    }

    @Override
    public NewBaseAttributeSet emptySet() {
      return new NewBaseAttributeSetImpl();
    }

    @Override
    public NewBaseAttributeSet emptySet(Comparator<? super NewBaseAttribute> comp) {
      return new NewBaseAttributeSetImpl(comp);
    }

    @Override
    public NewBaseAttributeSet value() {
        return this;
    }

    @Override
    public List<NewBaseAttribute> elements() {
        return Arrays.asList(toArray(new NewBaseAttribute[0]));
    }

}
